View source: R/A01-estimator-weibull.R
| compute_etau | R Documentation |
Implements Estimator I (AJE 2022, Eq. 2) combining propensity score weighting and inverse probability of censoring weighting to estimate counterfactual survival functions and treatment effects. Compute Etau Normalization Constant
compute_etau(
estimand,
method,
ps_matrix,
n_levels,
att_group = NULL,
treatment_levels = NULL
)
estimand |
Estimand type ("ATE", "ATT", or for overlap). |
method |
Method ("IPW" or "overlap"). |
ps_matrix |
Propensity score matrix [n x J]. |
n_levels |
Number of treatment levels. |
att_group |
Target group for ATT (if applicable). |
treatment_levels |
Vector of treatment levels. |
Numeric scalar Etau.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.